@@ -39,8 +39,8 @@ class ComputeThumbNailJob : public ThreadWeaver::Job
 {
 public:
     ComputeThumbNailJob(Image* image, ThreadWeaver::ResourceRestrictionPolicy* throttle);
-    int priority() const Q_DECL_OVERRIDE;
-    void run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thread) Q_DECL_OVERRIDE;
+    int priority() const override;
+    void run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thread) override;
 
 private:
     Image* m_image;
